#!/bin/bash
# Copyright (c) 2016-2018 Michael Stauber <mstauber@solarspeed.net>, SOLARSPEED.NET
# All Rights Reserved.

while getopts ":u:m:s:" opt; do
  case $opt in
    u) uuid="$OPTARG"
    ;;
    m) mount="$OPTARG"
    ;;
    s) script="$OPTARG"
    ;;
    \?) echo "Invalid option -$OPTARG" >&2
    ;;
  esac
done


if [ "$uuid" == '' ] || [ "$mount" == '' ] || [ "$script" == '' ];then
	echo "$0 usage:"
	echo " -u: Specify UUID of VPS that you want to RSYNC backup"
	echo " -m: Specify directory where you want to temporarily mount Snapshot"
	echo " -s: Specify (in quotes) the backup command you want to run inside the Snapshot area."
	echo ""
fi

if [ ! -d $mount ];then
	echo "ERROR: The directory specified via -m $mount doesn't exist!"
	echo ""
	exit
fi

if [ "$uuid" != "" ];then
	CHECK=$(/usr/bin/prlctl list $uuid|grep -v ^UUID | wc -l)
	if [ "$CHECK" -lt "1" ];then
		echo "ERROR: The UUID specified via -u $uuid doesn't exist!"
		echo ""
		exit
	fi
fi

if [ "$uuid" != '' ] && [ "$mount" != '' ] && [ "$script" != '' ];then
	# Known snapshot ID
	ID=$(uuidgen)
	WHEREAREWE=$(pwd)

	echo ""
	echo "Starting ..."
	echo ""
	echo "Mounting VPS-Snapshot with UUID $uuid to $mount"
	echo ""

	# Take a snapshot without suspending a CT:
	vzctl snapshot $uuid --id $ID --skip-suspend

	# Mount the snapshot taken
	vzctl snapshot-mount $uuid --id $ID --target $mount

	# Perform a backup using your favorite backup tool
	# (tar is just an example)
	cd $mount
	echo ""
	echo "Entering $mount and executing \"$script\" ..."
	echo ""
	$script
	echo ""	
	cd $WHEREAREWE

	# Unmount the snapshot
	vzctl snapshot-umount $uuid --id $ID

	# Delete (merge) the snapshot
	vzctl snapshot-delete $uuid --id $ID

	echo ""
	echo "SUCCESS: All done."
	echo ""
fi
exit
